@@ -117,7 +117,7 @@ static void bind_key_vec(leafp tree, size_t *keys, size_t n, Function func)
     s->func = func;
 }
 
-static void bind_key_string(char *key, Function func)
+static int bind_key_string(char *key, Function func)
 {
   int numkeys;
   size_t *keys;
@@ -125,7 +125,9 @@ static void bind_key_string(char *key, Function func)
   if ((numkeys = keystrtovec(key, &keys)) > 0) {
     bind_key_vec(leaf_tree, keys, numkeys, func);
     free(keys);
-  }
+    return TRUE;
+  } else
+    return FALSE;
 }
 
 static leafp search_key(leafp tree, size_t *keys, size_t n)
@@ -196,6 +198,7 @@ static leafp completion_scan(size_t key, size_t **keys, int *numkeys)
 DEFUN("self-insert-command", self_insert_command)
 /*+
 Insert the character you type.
+Whichever character you type to run this command is inserted.
 +*/
 {
   int uni, ret = TRUE;
@@ -312,7 +315,10 @@ void init_bindings(void)
   for (i = 0; i < fentry_table_size; i++)
     for (j = 0; j < 3; ++j)
       if (fentry_table[i].key[j] != NULL)
-        bind_key_string(fentry_table[i].key[j], fentry_table[i].func);
+        if (!bind_key_string(fentry_table[i].key[j], fentry_table[i].func)) {
+          fprintf(stderr, PACKAGE ": Key sequence %s is invalid in default bindings\n\n", fentry_table[i].key[j]);
+          exit(1);
+        }
 }
 
 static void recursive_free_bindings(leafp p)
@@ -479,6 +485,10 @@ sequence.
 
   if (arglist) {
     numkeys = keystrtovec(arglist->list_next->data, &keys);
+    if (numkeys == -1) {
+      minibuf_error("Key sequence %s is invalid", arglist->list_next->data);
+      return FALSE;
+    }
     name = arglist->list_next->list_next->data;
   } else {
     astr as;
