@@ -11,7 +11,7 @@ X0("auto-fill-mode", auto_fill_mode)
 X1("back-to-indentation", back_to_indentation,		"\\M-m")
 X2("backward-char", backward_char,			"\\C-b", "\\LEFT")
 X1("backward-delete-char", backward_delete_char,	"\\BACKSPACE")
-X1("backward-kill-word", backward_kill_word,		"\\M-\\DEL")
+X1("backward-kill-word", backward_kill_word,		"\\M-\\BACKSPACE")
 X1("backward-paragraph", backward_paragraph,		"\\M-{")
 X1("backward-sexp", backward_sexp,			"\\C-\\M-b")
 X1("backward-word", backward_word,			"\\M-b")
@@ -23,7 +23,7 @@ X0("cd", cd)
 X1("copy-region-as-kill", copy_region_as_kill,		"\\M-w")
 X2("copy-to-register", copy_to_register,		"\\C-xrx", "\\C-xrs")
 X1("delete-blank-lines", delete_blank_lines,		"\\C-x\\C-o")
-X2("delete-char", delete_char,				"\\C-d", "\\DEL")
+X2("delete-char", delete_char,				"\\C-d", "\\DELETE")
 X1("delete-horizontal-space", delete_horizontal_space,	"\\M-\\\\")
 X1("delete-other-windows", delete_other_windows,	"\\C-x1")
 X0("delete-region", delete_region)
@@ -81,7 +81,7 @@ X1("newline-and-indent", newline_and_indent,		"\\C-j")
 X2("next-line", next_line,				"\\C-n", "\\DOWN")
 X1("open-line", open_line,				"\\C-o")
 X1("other-window", other_window,			"\\C-xo")
-X1("overwrite-mode", overwrite_mode,			"\\INS")
+X1("overwrite-mode", overwrite_mode,			"\\INSERT")
 X2("previous-line", previous_line,			"\\C-p", "\\UP")
 X1("query-replace", query_replace,			"\\M-%")
 X1("quoted-insert", quoted_insert,			"\\C-q")
@@ -90,8 +90,8 @@ X0("replace-string", replace_string)
 X1("save-buffer", save_buffer,				"\\C-x\\C-s")
 X1("save-buffers-kill-zile", save_buffers_kill_zile,	"\\C-x\\C-c")
 X1("save-some-buffers", save_some_buffers,		"\\C-xs")
-X2("scroll-down", scroll_down,				"\\M-v", "\\NEXT")
-X2("scroll-up", scroll_up,				"\\C-v", "\\PRIOR")
+X2("scroll-down", scroll_down,				"\\M-v", "\\PRIOR")
+X2("scroll-up", scroll_up,				"\\C-v", "\\NEXT")
 X0("search-backward", search_backward)
 X0("search-backward-regexp", search_backward_regexp)
 X0("search-forward", search_forward)
