@@ -1,6 +1,6 @@
 /* Redisplay engine
    Copyright (c) 1997-2004 Sandro Sigala.
-   Copyright (c) 2003-2004 Reuben Thomas.
+   Copyright (c) 2003-2007 Reuben Thomas.
    All rights reserved.
 
    This file is part of Zile.
@@ -285,9 +285,9 @@ static char *make_screen_pos(Window *wp, char **buf)
 static void draw_status_line(size_t line, Window *wp)
 {
   size_t i;
-  int someflag = 0;
-  char *buf;
+  char *buf, *eol_type;
   Point pt = window_pt(wp);
+  astr as, bs;
 
   term_attrset(1, FONT_REVERSE);
 
@@ -295,28 +295,33 @@ static void draw_status_line(size_t line, Window *wp)
   for (i = 0; i < wp->ewidth; ++i)
     term_addch('-');
 
+  if (cur_bp->eol == coding_eol_cr)
+    eol_type = "(Mac)";
+  else if (cur_bp->eol == coding_eol_crlf)
+    eol_type = "(DOS)";
+  else
+    eol_type = ":";
+    
   term_move(line, 0);
-  term_printw("--%2s- %-18s (", make_mode_line_flags(wp), wp->bp->name);
-
-  if (wp->bp->flags & BFLAG_AUTOFILL) {
-    term_printw("Fill");
-    someflag = 1;
-  }
-  if (wp->bp->flags & BFLAG_OVERWRITE) {
-    term_printw("%sOvwrt", someflag ? " " : "");
-    someflag = 1;
-  }
-  if (thisflag & FLAG_DEFINING_MACRO) {
-    term_printw("%sDef", someflag ? " " : "");
-    someflag = 1;
-  }
-  if (wp->bp->flags & BFLAG_ISEARCH)
-    term_printw("%sIsearch", someflag ? " " : "");
-
-  term_printw(")--L%d--C%d--%s",
-              pt.n+1, get_goalc_wp(wp),
-              make_screen_pos(wp, &buf));
+  bs = astr_afmt(astr_new(), "(%d,%d)", pt.n+1, get_goalc_wp(wp));
+  as = astr_afmt(astr_new(), "--%s%2s  %-15s   %s %-9s (Text",
+                 eol_type, make_mode_line_flags(wp), wp->bp->name,
+                 make_screen_pos(wp, &buf), astr_cstr(bs));
   free(buf);
+  astr_delete(bs);
+
+  if (wp->bp->flags & BFLAG_AUTOFILL)
+    astr_cat_cstr(as, " Fill");
+  if (wp->bp->flags & BFLAG_OVERWRITE)
+    astr_cat_cstr(as, " Ovwrt");
+  if (thisflag & FLAG_DEFINING_MACRO)
+    astr_cat_cstr(as, " Def");
+  if (wp->bp->flags & BFLAG_ISEARCH)
+    astr_cat_cstr(as, " Isearch");
+
+  astr_cat_char(as, ')');
+  term_addnstr(astr_cstr(as), min(term_width(), astr_len(as)));
+  astr_delete(as);
 
   term_attrset(1, FONT_NORMAL);
 }
@@ -396,19 +401,3 @@ void term_addnstr(const char *s, size_t len)
   for (i = 0; i < len; i++)
     term_addch(*s++);
 }
-
-/*
- * printf on the terminal
- */
-int term_printw(const char *fmt, ...)
-{
-  char *buf;
-  int res = 0;
-  va_list ap;
-  va_start(ap, fmt);
-  res = zvasprintf(&buf, fmt, ap);
-  va_end(ap);
-  term_addnstr(buf, strlen(buf));
-  free(buf);
-  return res;
-}
